==> netdev-0.8.0.tar.gz: netdev-0.8.0/netdev/vendors/aruba/aruba_aos_8.py <==
"""Subclass specific to Aruba AOS 8.x"""

import re

from ..ios_like import IOSLikeDevice
from ..logger import logger


class ArubaAOS8(IOSLikeDevice):
    """Class for working with Aruba OS 8.X"""

    _disable_paging_command = 'no paging'
    """Command for disabling paging"""

    _config_exit = 'end'
    """Command for existing from configuration mode to privilege exec"""

    _config_check = '] (config'
    """Checking string in prompt. If it's exist im prompt - we are in configuration mode"""

    _pattern = r"\({}.*?\) [*^]?\[.*?\] (\(.*?\))?\s?[{}]"
    """Pattern for using in reading buffer. When it found processing ends"""

    async def _set_base_prompt(self):
        """
        Setting two important vars:

            base_prompt - textual prompt in CLI (usually hostname)
            base_pattern - regexp for finding the end of command. It's platform specific parameter

        For Aruba AOS 8 devices base_pattern is "(prompt) [node] (\(.*?\))?\s?[#|>]
        """
        logger.info("Host {}: Setting base prompt".format(self._host))
        prompt = await self._find_prompt()
        prompt = prompt.split(')')[0]
        # Strip off trailing terminator
        self._base_prompt = prompt[1:]
        delimiters = map(re.escape, type(self)._delimiter_list)
        delimiters = r"|".join(delimiters)
        base_prompt = re.escape(self._base_prompt[:12])
        pattern = type(self)._pattern
        self._base_pattern = pattern.format(base_prompt, delimiters)
        logger.debug("Host {}: Base Prompt: {}".format(self._host, self._base_prompt))
        logger.debug("Host {}: Base Pattern: {}".format(self._host, self._base_pattern))
        return self._base_prompt

==> netdev-0.9.3.tar.gz: netdev-0.9.3/netdev/vendors/aruba/aruba_aos_8.py <==
"""Subclass specific to Aruba AOS 8.x"""

import re

from netdev.logger import logger
from netdev.vendors.ios_like import IOSLikeDevice


class ArubaAOS8(IOSLikeDevice):
    """Class for working with Aruba OS 8.X"""

    _disable_paging_command = "no paging"
    """Command for disabling paging"""

    _config_exit = "end"
    """Command for existing from configuration mode to privilege exec"""

    _config_check = "] (config"
    """Checking string in prompt. If it's exist im prompt - we are in configuration mode"""

    _pattern = r"\({prompt}.*?\) [*^]?\[.*?\] (\(.*?\))?\s?[{delimiters}]"
    """Pattern for using in reading buffer. When it found processing ends"""

    async def _set_base_prompt(self):
        """
        Setting two important vars:

            base_prompt - textual prompt in CLI (usually hostname)
            base_pattern - regexp for finding the end of command. It's platform specific parameter

        For Aruba AOS 8 devices base_pattern is "(prompt) [node] (\(.*?\))?\s?[#|>]
        """
        logger.info("Host {}: Setting base prompt".format(self._host))
        prompt = await self._find_prompt()
        prompt = prompt.split(")")[0]
        # Strip off trailing terminator
        self._base_prompt = prompt[1:]
        delimiters = map(re.escape, type(self)._delimiter_list)
        delimiters = r"|".join(delimiters)
        base_prompt = re.escape(self._base_prompt[:12])
        pattern = type(self)._pattern
        self._base_pattern = pattern.format(prompt=base_prompt, delimiters=delimiters)
        logger.debug("Host {}: Base Prompt: {}".format(self._host, self._base_prompt))
        logger.debug("Host {}: Base Pattern: {}".format(self._host, self._base_pattern))
        return self._base_prompt
